@@ -13,6 +13,7 @@ import (
 	"github.com/noobaa/noobaa-operator/v5/pkg/options"
 	"github.com/noobaa/noobaa-operator/v5/pkg/system"
 	"github.com/noobaa/noobaa-operator/v5/pkg/util"
+	"github.com/noobaa/noobaa-operator/v5/pkg/validations"
 
 	"github.com/spf13/cobra"
 	corev1 "k8s.io/api/core/v1"
@@ -53,6 +54,7 @@ func CmdCreate() *cobra.Command {
 	}
 	cmd.AddCommand(
 		CmdCreateAWSS3(),
+		CmdCreateAWSSTSS3(),
 		CmdCreateS3Compatible(),
 		CmdCreateIBMCos(),
 		CmdCreateAzureBlob(),
@@ -62,6 +64,28 @@ func CmdCreate() *cobra.Command {
 	return cmd
 }
 
+// CmdCreateAWSSTSS3 returns a cli command
+func CmdCreateAWSSTSS3() *cobra.Command {
+	cmd := &cobra.Command{
+		Use:   "aws-sts-s3 <backing-store-name>",
+		Short: "Create aws-sts-s3 backing store",
+		Run:   RunCreateAWSSTSS3,
+	}
+	cmd.Flags().String(
+		"target-bucket", "",
+		"The target bucket name on the cloud",
+	)
+	cmd.Flags().String(
+		"aws-sts-arn", "",
+		"The AWS STS Role ARN which will assume role",
+	)
+	cmd.Flags().String(
+		"region", "",
+		"The AWS bucket region",
+	)
+	return cmd
+}
+
 // CmdCreateAWSS3 returns a CLI command
 func CmdCreateAWSS3() *cobra.Command {
 	cmd := &cobra.Command{
@@ -340,6 +364,11 @@ func createCommon(cmd *cobra.Command, args []string, storeType nbv1.StoreType, p
 
 	populate(backStore, secret)
 
+	validationErr := validations.ValidateBackingStore(*backStore)
+	if validationErr != nil {
+		log.Fatalf(`❌ %s %s`, validationErr, cmd.UsageString())
+	}
+
 	// Create backing store CR
 	util.Panic(controllerutil.SetControllerReference(sys, backStore, scheme.Scheme))
 	if !util.KubeCreateFailExisting(backStore) {
@@ -365,6 +394,56 @@ func createCommon(cmd *cobra.Command, args []string, storeType nbv1.StoreType, p
 	}
 }
 
+// RunCreateAWSSTSS3 runs a cli command
+func RunCreateAWSSTSS3(cmd *cobra.Command, args []string) {
+	log := util.Logger()
+	if len(args) != 1 || args[0] == "" {
+		log.Fatalf(`❌ Missing expected arguments: <backing-store-name> %s`, cmd.UsageString())
+	}
+	name := args[0]
+	o := util.KubeObject(bundle.File_deploy_crds_noobaa_io_v1alpha1_noobaa_cr_yaml)
+	sys := o.(*nbv1.NooBaa)
+	sys.Name = options.SystemName
+	sys.Namespace = options.Namespace
+
+	o = util.KubeObject(bundle.File_deploy_crds_noobaa_io_v1alpha1_backingstore_cr_yaml)
+	backStore := o.(*nbv1.BackingStore)
+	backStore.Name = name
+	backStore.Namespace = options.Namespace
+	backStore.Spec = nbv1.BackingStoreSpec{Type: nbv1.StoreTypeAWSS3}
+
+	if !util.KubeCheck(sys) {
+		log.Fatalf(`❌ Could not find NooBaa system %q in namespace %q`, sys.Name, sys.Namespace)
+	}
+
+	err := util.KubeClient().Get(util.Context(), util.ObjectKey(backStore), backStore)
+	if err == nil {
+		log.Fatalf(`❌ BackingStore %q already exists in namespace %q`, backStore.Name, backStore.Namespace)
+	}
+	awsSTSARN := util.GetFlagStringOrPrompt(cmd, "aws-sts-arn")
+	targetBucket := util.GetFlagStringOrPrompt(cmd, "target-bucket")
+	region, _ := cmd.Flags().GetString("region")
+	backStore.Spec.AWSS3 = &nbv1.AWSS3Spec{
+		TargetBucket:  targetBucket,
+		Region:        region,
+		AWSSTSRoleARN: &awsSTSARN,
+	}
+	// Create backing store CR
+	util.Panic(controllerutil.SetControllerReference(sys, backStore, scheme.Scheme))
+	if !util.KubeCreateFailExisting(backStore) {
+		log.Fatalf(`❌ Could not create BackingStore %q in Namespace %q (conflict)`, backStore.Name, backStore.Namespace)
+	}
+	log.Printf("")
+	util.PrintThisNoteWhenFinishedApplyingAndStartWaitLoop()
+	log.Printf("")
+	log.Printf("BackingStore Wait Ready:")
+	if WaitReady(backStore) {
+		log.Printf("")
+		log.Printf("")
+		RunStatus(cmd, args)
+	}
+}
+
 // RunCreateAWSS3 runs a CLI command
 func RunCreateAWSS3(cmd *cobra.Command, args []string) {
 	createCommon(cmd, args, nbv1.StoreTypeAWSS3, func(backStore *nbv1.BackingStore, secret *corev1.Secret) {
@@ -578,35 +657,35 @@ func RunCreatePVPool(cmd *cobra.Command, args []string) {
 			}
 		}
 
-		var requestCPUQuantity, requestMemoryQuantity,  limitCPUQuantity, limitMemoryQuantity resource.Quantity
+		var requestCPUQuantity, requestMemoryQuantity, limitCPUQuantity, limitMemoryQuantity resource.Quantity
 		var err error
 		requestCPUQuantity, err = resource.ParseQuantity(requestCPU)
 		if err != nil {
 			log.Fatalf(`❌ Could not parse request cpu %q`,
-			requestCPU)
+				requestCPU)
 		}
 		requestMemoryQuantity, err = resource.ParseQuantity(requestMemory)
 		if err != nil {
 			log.Fatalf(`❌ Could not parse request Memory %q`,
-			requestMemory)
+				requestMemory)
 		}
 		limitCPUQuantity, err = resource.ParseQuantity(limitCPU)
 		if err != nil {
 			log.Fatalf(`❌ Could not parse limit cpu %q`,
-			limitCPU)
+				limitCPU)
 		}
 		limitMemoryQuantity, err = resource.ParseQuantity(limitMemory)
 		if err != nil {
 			log.Fatalf(`❌ Could not parse limit Memory %q`,
-			limitMemory)
+				limitMemory)
 		}
 		if requestCPUQuantity.Cmp(limitCPUQuantity) > 0 {
 			log.Fatalf(`❌ Request CPU %v is larger than limit CPU %v`,
-			requestCPUQuantity.String(), limitCPUQuantity.String())
+				requestCPUQuantity.String(), limitCPUQuantity.String())
 		}
 		if requestMemoryQuantity.Cmp(limitMemoryQuantity) > 0 {
 			log.Fatalf(`❌ Request memory %v is larger than limit memory %v`,
-			requestMemoryQuantity.String(), limitMemoryQuantity.String())
+				requestMemoryQuantity.String(), limitMemoryQuantity.String())
 		}
 
 		backStore.Spec.PVPool = &nbv1.PVPoolSpec{
@@ -615,11 +694,11 @@ func RunCreatePVPool(cmd *cobra.Command, args []string) {
 			VolumeResources: &corev1.ResourceRequirements{
 				Requests: corev1.ResourceList{
 					corev1.ResourceStorage: *resource.NewQuantity(int64(pvSizeGB)*1024*1024*1024, resource.BinarySI),
-					corev1.ResourceCPU: requestCPUQuantity,
-					corev1.ResourceMemory: requestMemoryQuantity,
+					corev1.ResourceCPU:     requestCPUQuantity,
+					corev1.ResourceMemory:  requestMemoryQuantity,
 				},
 				Limits: corev1.ResourceList{
-					corev1.ResourceCPU: limitCPUQuantity,
+					corev1.ResourceCPU:    limitCPUQuantity,
 					corev1.ResourceMemory: limitMemoryQuantity,
 				},
 			},
@@ -757,17 +836,18 @@ func RunStatus(cmd *cobra.Command, args []string) {
 		log.Fatalf(`❌ Could not get BackingStore %q in namespace %q`,
 			backStore.Name, backStore.Namespace)
 	}
-
 	secretRef := GetBackingStoreSecret(backStore)
-	if secretRef != nil {
-		secret.Name = secretRef.Name
-		secret.Namespace = secretRef.Namespace
-		if secret.Namespace == "" {
-			secret.Namespace = backStore.Namespace
-		}
-		if !util.KubeCheck(secret) {
-			log.Errorf(`❌ Could not get Secret %q in namespace %q`,
-				secret.Name, secret.Namespace)
+	if !util.IsSTSClusterBS(backStore) {
+		if secretRef != nil {
+			secret.Name = secretRef.Name
+			secret.Namespace = secretRef.Namespace
+			if secret.Namespace == "" {
+				secret.Namespace = backStore.Namespace
+			}
+			if !util.KubeCheck(secret) {
+				log.Errorf(`❌ Could not get Secret %q in namespace %q`,
+					secret.Name, secret.Namespace)
+			}
 		}
 	}
 
@@ -780,10 +860,8 @@ func RunStatus(cmd *cobra.Command, args []string) {
 	fmt.Print(string(output))
 	fmt.Println()
 	if secretRef != nil {
-		fmt.Println("# Secret data:")
-		output, err = sigyaml.Marshal(secret.StringData)
+		_, err = sigyaml.Marshal(secret.StringData)
 		util.Panic(err)
-		fmt.Print(string(output))
 		fmt.Println()
 	}
 }
