@@ -4,7 +4,6 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	math "math"
 	"net/url"
 	"os"
 	"reflect"
@@ -18,6 +17,7 @@ import (
 	"github.com/noobaa/noobaa-operator/v5/pkg/options"
 	"github.com/noobaa/noobaa-operator/v5/pkg/system"
 	"github.com/noobaa/noobaa-operator/v5/pkg/util"
+	"github.com/noobaa/noobaa-operator/v5/pkg/validations"
 
 	cephv1 "github.com/rook/rook/pkg/apis/ceph.rook.io/v1"
 	"github.com/sirupsen/logrus"
@@ -154,7 +154,7 @@ func (r *Reconciler) Reconcile() (reconcile.Result, error) {
 		return reconcile.Result{}, nil // final state
 	}
 
-	if 	err := r.LoadBackingStoreSecret(); err != nil {
+	if err := r.LoadBackingStoreSecret(); err != nil {
 		return r.completeReconcile(err)
 	}
 
@@ -256,33 +256,35 @@ func (r *Reconciler) ReconcilePhases() error {
 
 // LoadBackingStoreSecret loads the secret to the reconciler struct
 func (r *Reconciler) LoadBackingStoreSecret() error {
-	secretRef := GetBackingStoreSecret(r.BackingStore)
-	if secretRef != nil {
-		r.Secret.Name = secretRef.Name
-		r.Secret.Namespace = secretRef.Namespace
-		if r.Secret.Namespace == "" {
-			r.Secret.Namespace = r.BackingStore.Namespace
-		}
-		if r.Secret.Name == "" {
-			if r.BackingStore.Spec.Type != nbv1.StoreTypePVPool {
-				return util.NewPersistentError("EmptySecretName",
-					"BackingStore Secret reference has an empty name")
+	if !util.IsSTSClusterBS(r.BackingStore) {
+		secretRef := GetBackingStoreSecret(r.BackingStore)
+		if secretRef != nil {
+			r.Secret.Name = secretRef.Name
+			r.Secret.Namespace = secretRef.Namespace
+			if r.Secret.Namespace == "" {
+				r.Secret.Namespace = r.BackingStore.Namespace
 			}
-			r.Secret.Name = fmt.Sprintf("backing-store-%s-%s", nbv1.StoreTypePVPool, r.BackingStore.Name)
-			r.Secret.Namespace = r.BackingStore.Namespace
-			r.Secret.StringData = map[string]string{}
-			r.Secret.Data = nil
-
-			if !util.KubeCheck(r.Secret) {
-				r.Own(r.Secret)
-				if !util.KubeCreateFailExisting(r.Secret) {
+			if r.Secret.Name == "" {
+				if r.BackingStore.Spec.Type != nbv1.StoreTypePVPool {
 					return util.NewPersistentError("EmptySecretName",
-						fmt.Sprintf("Could not create Secret %q in Namespace %q (conflict)", r.Secret.Name, r.Secret.Namespace))
+						"BackingStore Secret reference has an empty name")
 				}
-			}
+				r.Secret.Name = fmt.Sprintf("backing-store-%s-%s", nbv1.StoreTypePVPool, r.BackingStore.Name)
+				r.Secret.Namespace = r.BackingStore.Namespace
+				r.Secret.StringData = map[string]string{}
+				r.Secret.Data = nil
 
+				if !util.KubeCheck(r.Secret) {
+					r.Own(r.Secret)
+					if !util.KubeCreateFailExisting(r.Secret) {
+						return util.NewPersistentError("EmptySecretName",
+							fmt.Sprintf("Could not create Secret %q in Namespace %q (conflict)", r.Secret.Name, r.Secret.Namespace))
+					}
+				}
+
+			}
+			util.KubeCheck(r.Secret)
 		}
-		util.KubeCheck(r.Secret)
 	}
 	return nil
 }
@@ -330,6 +332,11 @@ func (r *Reconciler) ReconcilePhaseVerifying() error {
 		"noobaa operator started phase 1/3 - \"Verifying\"",
 	)
 
+	err := validations.ValidateBackingStore(*r.BackingStore)
+	if err != nil {
+		return util.NewPersistentError("BackingStoreValidationError", err.Error())
+	}
+
 	if r.NooBaa.UID == "" {
 		return util.NewPersistentError("MissingSystem",
 			fmt.Sprintf("NooBaa system %q not found or deleted", r.NooBaa.Name))
@@ -406,10 +413,10 @@ func (r *Reconciler) finalizeCore() error {
 					allowedBuckets.PermissionList = []string{}
 				}
 				err := r.NBClient.UpdateAccountS3Access(nb.UpdateAccountS3AccessParams{
-					Email:        account.Email,
-					S3Access:     account.HasS3Access,
-					DefaultResource:  &internalPoolName,
-					AllowBuckets: &allowedBuckets,
+					Email:           account.Email,
+					S3Access:        account.HasS3Access,
+					DefaultResource: &internalPoolName,
+					AllowBuckets:    &allowedBuckets,
 				})
 				if err != nil {
 					return err
@@ -528,34 +535,14 @@ func (r *Reconciler) ReadSystemInfo() error {
 			))
 		}
 
-		const maxPoolNameLength = int(43)
-		if len(r.BackingStore.Name) > maxPoolNameLength {
-			return util.NewPersistentError("TooLongPoolName",
-				fmt.Sprintf("NooBaa BackingStore %q is in rejected phase due to too long pvpool backingstore name, max allowed is %d", r.BackingStore.Name, maxPoolNameLength))
-		}
-
 		const defaultVolumeSize = int64(20 * 1024 * 1024 * 1024) // 20Gi=20*1024^3
-		const minimalVolumeSize = int64(16 * 1024 * 1024 * 1024) // 16Gi=16*1024^3
 		var volumeSize int64
 		pvPool := r.BackingStore.Spec.PVPool
 		if pvPool.VolumeResources != nil {
 			qty := pvPool.VolumeResources.Requests[corev1.ResourceName(corev1.ResourceStorage)]
 			volumeSize = qty.Value()
-		}
-		if volumeSize < minimalVolumeSize {
-			if volumeSize == 0 {
-				volumeSize = int64(defaultVolumeSize)
-			} else {
-				return util.NewPersistentError("SmallVolumeSize",
-					fmt.Sprintf("NooBaa BackingStore %q is in rejected phase due to insufficient size, min is %d=%gGB", r.BackingStore.Name, minimalVolumeSize, (float64(minimalVolumeSize)/(math.Pow(1024, 3)))))
-			}
-		}
-
-		const maxNumVolumes = int(20)
-		var numVolumes = int(pvPool.NumVolumes)
-		if numVolumes > maxNumVolumes {
-			return util.NewPersistentError("MaxNumVolumes",
-				fmt.Sprintf("NooBaa BackingStore %q is in rejected phase due to large amount of volumes, max is %d", r.BackingStore.Name, maxNumVolumes))
+		} else {
+			volumeSize = int64(defaultVolumeSize)
 		}
 
 		if pool == nil {
@@ -657,9 +644,14 @@ func (r *Reconciler) MakeExternalConnectionParams() (*nb.AddExternalConnectionPa
 	switch r.BackingStore.Spec.Type {
 
 	case nbv1.StoreTypeAWSS3:
-		conn.EndpointType = nb.EndpointTypeAws
-		conn.Identity = r.Secret.StringData["AWS_ACCESS_KEY_ID"]
-		conn.Secret = r.Secret.StringData["AWS_SECRET_ACCESS_KEY"]
+		if util.IsSTSClusterBS(r.BackingStore) {
+			conn.EndpointType = nb.EndpointTypeAwsSTS
+			conn.AWSSTSARN = *r.BackingStore.Spec.AWSS3.AWSSTSRoleARN
+		} else {
+			conn.EndpointType = nb.EndpointTypeAws
+			conn.Identity = r.Secret.StringData["AWS_ACCESS_KEY_ID"]
+			conn.Secret = r.Secret.StringData["AWS_SECRET_ACCESS_KEY"]
+		}
 		awsS3 := r.BackingStore.Spec.AWSS3
 		u := url.URL{
 			Scheme: "https",
@@ -670,6 +662,7 @@ func (r *Reconciler) MakeExternalConnectionParams() (*nb.AddExternalConnectionPa
 		}
 		if awsS3.Region != "" {
 			u.Host = fmt.Sprintf("s3.%s.amazonaws.com", awsS3.Region)
+			conn.Region = awsS3.Region
 		}
 		conn.Endpoint = u.String()
 
@@ -682,10 +675,6 @@ func (r *Reconciler) MakeExternalConnectionParams() (*nb.AddExternalConnectionPa
 			conn.AuthMethod = "AWS_V4"
 		} else if s3Compatible.SignatureVersion == nbv1.S3SignatureVersionV2 {
 			conn.AuthMethod = "AWS_V2"
-		} else if s3Compatible.SignatureVersion != "" {
-			return nil, util.NewPersistentError("InvalidSignatureVersion",
-				fmt.Sprintf("Invalid s3 signature version %q for backing store %q",
-					s3Compatible.SignatureVersion, r.BackingStore.Name))
 		}
 		if s3Compatible.Endpoint == "" {
 			u := url.URL{
@@ -732,10 +721,6 @@ func (r *Reconciler) MakeExternalConnectionParams() (*nb.AddExternalConnectionPa
 			conn.AuthMethod = "AWS_V4"
 		} else if IBMCos.SignatureVersion == nbv1.S3SignatureVersionV2 {
 			conn.AuthMethod = "AWS_V2"
-		} else if IBMCos.SignatureVersion != "" {
-			return nil, util.NewPersistentError("InvalidSignatureVersion",
-				fmt.Sprintf("Invalid s3 signature version %q for backing store %q",
-					IBMCos.SignatureVersion, r.BackingStore.Name))
 		}
 		if IBMCos.Endpoint == "" {
 			u := url.URL{
@@ -804,10 +789,11 @@ func (r *Reconciler) MakeExternalConnectionParams() (*nb.AddExternalConnectionPa
 		return nil, util.NewPersistentError("InvalidType",
 			fmt.Sprintf("Invalid backing store type %q", r.BackingStore.Spec.Type))
 	}
-
-	if !util.IsStringGraphicOrSpacesCharsOnly(conn.Identity) || !util.IsStringGraphicOrSpacesCharsOnly(conn.Secret) {
-		return nil, util.NewPersistentError("InvalidSecret",
-			fmt.Sprintf("Invalid secret containing non graphic characters (perhaps not base64 encoded?) %q", r.Secret.Name))
+	if !util.IsSTSClusterBS(r.BackingStore) {
+		if !util.IsStringGraphicOrSpacesCharsOnly(conn.Identity) || !util.IsStringGraphicOrSpacesCharsOnly(conn.Secret) {
+			return nil, util.NewPersistentError("InvalidSecret",
+				fmt.Sprintf("Invalid secret containing non graphic characters (perhaps not base64 encoded?) %q", r.Secret.Name))
+		}
 	}
 
 	return conn, nil
@@ -871,8 +857,8 @@ func (r *Reconciler) ReconcileExternalConnection() error {
 		fallthrough
 	case nb.ExternalConnectionInvalidEndpoint:
 		if time.Since(r.BackingStore.CreationTimestamp.Time) < 5*time.Minute {
-			r.Logger.Infof("got invalid endopint. requeuing for 5 minutes to make sure it is not a temporary connection issue")
-			return fmt.Errorf("got invalid endopint. requeue again")
+			r.Logger.Infof("got invalid endpoint. requeuing for 5 minutes to make sure it is not a temporary connection issue")
+			return fmt.Errorf("got invalid endpoint. requeue again")
 		}
 		fallthrough
 	case nb.ExternalConnectionTimeSkew:
@@ -1109,7 +1095,7 @@ func (r *Reconciler) needUpdate(pod *corev1.Pod) bool {
 		envVar := util.GetEnvVariable(&c.Env, name)
 		val, ok := os.LookupEnv(name)
 		if (envVar == nil && ok) || (envVar != nil && (!ok || envVar.Value != val)) {
-			r.Logger.Warnf("Change in Env varaibles detected: os(%s) container(%v)", val, envVar)
+			r.Logger.Warnf("Change in Env variables detected: os(%s) container(%v)", val, envVar)
 			return true
 		}
 	}
@@ -1306,14 +1292,14 @@ func (r *Reconciler) reconcileResources(src, dst *corev1.ResourceList, minCPU, m
 		if qty, ok := (*src)[corev1.ResourceCPU]; ok {
 			if qty.Cmp(minCPU) < 0 {
 				return util.NewPersistentError("MinRequestCpu",
-				fmt.Sprintf("NooBaa BackingStore %v is in rejected phase due to small cpu request %v, min is %v", r.BackingStore.Name, qty.String(), minCPU.String()))
+					fmt.Sprintf("NooBaa BackingStore %v is in rejected phase due to small cpu request %v, min is %v", r.BackingStore.Name, qty.String(), minCPU.String()))
 			}
 			cpu = qty
 		}
 		if qty, ok := (*src)[corev1.ResourceMemory]; ok {
 			if qty.Cmp(minMem) < 0 {
 				return util.NewPersistentError("MinRequestCpu",
-				fmt.Sprintf("NooBaa BackingStore %v is in rejected phase due to small memory request %v, min is %v", r.BackingStore.Name, qty.String(), minMem.String()))
+					fmt.Sprintf("NooBaa BackingStore %v is in rejected phase due to small memory request %v, min is %v", r.BackingStore.Name, qty.String(), minMem.String()))
 			}
 			mem = qty
 		}
