@@ -176,7 +176,7 @@ function install {
     local use_obc_cleanup_policy
     
     [ $((RANDOM%2)) -gt 0 ] && use_obc_cleanup_policy="--use-obc-cleanup-policy"
-    test_noobaa install --mini ${use_obc_cleanup_policy}
+    test_noobaa install --mini --admission ${use_obc_cleanup_policy}
 
     local status=$(kuberun silence get noobaa noobaa -o 'jsonpath={.status.phase}')
     while [ "${status}" != "Ready" ]
@@ -193,6 +193,13 @@ function noobaa_install {
     test_noobaa status
     kuberun get noobaa
     kuberun describe noobaa
+    test_admission_deployment
+}
+
+function test_admission_deployment {
+    kuberun get Secret "admission-webhook-secret"
+    kuberun get ValidatingWebhookConfiguration "admission-validation-webhook"
+    kuberun get Service "admission-webhook-service"
 }
 
 function check_core_config_map {
@@ -483,6 +490,13 @@ function bucketclass_cycle {
     echo_time "✅  bucketclass cycle is done"
 }
 
+function bz_2038884 {
+    test_noobaa bucketclass create placement-bucketclass testbucketclass --backingstores=noobaa-default-backing-store
+    test_noobaa obc create --bucketclass=testbucketclass testobc
+    test_noobaa bucketclass delete testbucketclass
+    test_noobaa obc delete testobc
+}
+
 function check_obc {
     local bucket
     test_noobaa obc list
@@ -523,6 +537,104 @@ function obc_cycle {
     echo_time "✅  obc cycle is done"
 }
 
+function account_cycle {
+    local buckets=($(test_noobaa silence bucket list  | grep -v "BUCKET-NAME" | awk '{print $1}'))
+    local backingstores=($(test_noobaa silence backingstore list | grep -v "NAME" | awk '{print $1}'))
+    test_noobaa account create account1 --allowed_buckets ${buckets[0]} --default_resource ${backingstores[0]}
+    test_noobaa account create account2 --allowed_buckets ${buckets[0]},${buckets[1]} --allow_bucket_create=false # no need for default_resource
+    test_noobaa account create account3 --full_permission # default_resource should be the system default
+    test_noobaa should_fail account create account4 --default_resource ${backingstores[0]} # missing allowed_bucket
+    test_noobaa should_fail account create account5 --full_permission --allowed_buckets ${buckets[0]},${buckets[1]} # can't have both
+    test_noobaa should_fail account create account6 --allowed_buckets no_such_bucket --default_resource ${backingstores[0]}
+    test_noobaa should_fail account create account7 --full_permission --default_resource no_such_backingstore
+    #account1 is have a secret but and have CRD
+    account_regenerate_keys account1
+    #admin account is have a secret but no CRD 
+    account_regenerate_keys "admin@noobaa.io"
+    #admin account is don't have a secret and don't have CRD 
+    account_regenerate_keys "operator@noobaa.io"
+    # testing account reset password
+    account_reset_password "admin@noobaa.io"
+    # testing nsfs accounts
+    account_nsfs_cycle
+    echo_time "✅  noobaa account cycle is done"
+}
+
+function account_regenerate_keys {
+    local account=${1}
+    local AWS_ACCESS_KEY_ID
+    local AWS_SECRET_ACCESS_KEY
+    while read line
+    do
+        if [[ ${line} =~ (AWS_ACCESS_KEY_ID|AWS_SECRET_ACCESS_KEY) ]]
+        then
+            eval $(echo ${line//\"/} | sed -e 's/ //g' -e 's/:/=/g')
+        fi
+    done < <(test_noobaa account status ${account})
+
+    local ACCESS_KEY_ID_before=${AWS_ACCESS_KEY_ID}
+    local SECRET_ACCESS_KEY_before=${AWS_SECRET_ACCESS_KEY}
+    while read line
+    do
+        if [[ ${line} =~ (AWS_ACCESS_KEY_ID|AWS_SECRET_ACCESS_KEY) ]]
+        then
+            eval $(echo ${line//\"/} | sed -e 's/ //g' -e 's/:/=/g')
+        fi
+    done < <(yes | test_noobaa account regenerate ${account})
+
+    if [ "${AWS_ACCESS_KEY_ID}" == "${ACCESS_KEY_ID_before}" ]
+    then
+        echo_time "❌ Looks like the ACCESS_KEY were not regenerated, Exiting"
+        exit 1
+    fi
+
+    if [ "${AWS_SECRET_ACCESS_KEY}" == "${SECRET_ACCESS_KEY_before}" ]
+    then
+        echo_time "❌ Looks like the SECRET_ACCESS were not regenerated, Exiting"
+        exit 1
+    fi
+}
+
+function account_reset_password {
+    local account=${1}
+    local password
+    eval $(get_admin_password)
+    #reset password should work
+    test_noobaa account passwd ${account} --old-password ${password} --new-password "test" --retype-new-password "test"
+    # Should fail if the old password is not correct
+    test_noobaa should_fail account passwd ${account} --old-password "test1" --new-password "test" --retype-new-password "test"
+    # Should fail if we got the same password as the old one
+    test_noobaa should_fail account passwd ${account} --old-password "test" --new-password "test" --retype-new-password "test"
+    # Should fail if we got the same password twice 
+    test_noobaa should_fail account passwd ${account} --old-password "test" --new-password "test1" --retype-new-password "test2"
+}
+
+function get_admin_password {
+    local password
+    while read line
+    do
+        if [[ ${line} =~ "password" ]]
+        then
+            password=$(echo ${line//\"/} | sed -e 's/ //g' -e 's/:/=/g')
+        fi
+    done < <(yes | test_noobaa status)
+    echo ${password}
+}
+
+function account_nsfs_cycle {
+    local default_resource= "fs1"
+    # Creating namespacestore to use by the account 
+    test_noobaa namespacestore create nsfs ${default_resource} --pvc-name='nsfs-vol' --fs-backend='GPFS'
+    # Testing that we can create account using namespacestore
+    test_noobaa account create fsaccount1 --full_permission --default_resource ${default_resource} --nsfs_account_config --uid 123 --gid 456
+    # should fail if the default_resource does not exists
+    test_noobaa should_fail account create fsaccount2 --full_permission --default_resource not_exists --nsfs_account_config --uid 123 --gid 456
+    # should fail if the uid is not a number   
+    test_noobaa should_fail account create fsaccount3 --full_permission --default_resource ${default_resource} --nsfs_account_config --uid fail --gid 456
+    # should fail if the gid is not a number
+    test_noobaa should_fail account create fsaccount4 --full_permission --default_resource ${default_resource} --nsfs_account_config --uid 123 --gid fail
+}
+
 function delete_backingstore_path {
     local object_bucket backing_store
     local backingstore=($(test_noobaa silence backingstore list | grep -v "NAME" | awk '{print $1}'))
@@ -615,6 +727,15 @@ function delete_namespacestore_path {
     echo_time "✅  delete ${namespacestore[1]} and ${namespacestore[0]} path is done"
 }
 
+function delete_account {
+    local accounts=($(test_noobaa silence accounts list | grep -v "NAME" | awk '{print $1}'))
+    for account in ${accounts[@]}
+    do
+        test_noobaa account delete ${account}
+    done
+    echo_time "✅  delete accounts is done"
+}
+
 function check_deletes {
     echo_time "💬  Starting the delete cycle"
     local obc=($(test_noobaa silence obc list | grep -v "NAME\|default" | awk '{print $2}'))
@@ -625,6 +746,7 @@ function check_deletes {
     test_noobaa backingstore list
     delete_backingstore_path
     delete_namespacestore_path
+    delete_accounts
     echo_time "✅  delete cycle is done"
 }
 
@@ -716,3 +838,39 @@ function check_backingstore {
     echo_time "💬  Deleting bucket testbucket"
     test_noobaa bucket delete "testbucket"
 }
+
+function check_dbdump {
+    echo_time "💬  Generating db dump"
+
+    # Generate db dump at /tmp/<random_dir>
+    rand_dir=`tr -dc A-Za-z0-9 </dev/urandom | head -c 13 ; echo ''`
+    mkdir /tmp/$rand_dir
+    test_noobaa db-dump --dir /tmp/$rand_dir
+
+    # Check whether dump was created
+    dump_file_name=`ls -l /tmp/$rand_dir | grep noobaa_db_dump | awk '{ print $9 }'`
+    if [ ! -f "/tmp/$rand_dir/$dump_file_name" ]
+    then
+        echo_time "❌  db dump was not generated"
+        exit 1
+    fi
+
+    # Remove dump file
+    rm /tmp/$rand_dir/$dump_file_name
+
+    # Generate db dump through diagnose API
+    echo_time "💬  Generating db dump through diagnose"
+    test_noobaa diagnose --db-dump --dir /tmp/$rand_dir
+
+    # Check whether dump was created
+    diagnose_file_name=`ls -l /tmp/$rand_dir | grep noobaa_diagnostics | awk '{ print $9 }'`
+    dump_file_name=`ls -l /tmp/$rand_dir | grep noobaa_db_dump | awk '{ print $9 }'`
+    if [ ! -f "/tmp/$rand_dir/$dump_file_name" ]
+    then
+        echo_time "❌  db dump was not generated"
+        exit 1
+    fi
+
+    # Remove diagnostics and dump files
+    rm -rf /tmp/$rand_dir
+}
